@@ -1,4 +1,5 @@
 from bs4 import BeautifulSoup, Tag
+from pandas import DataFrame
 from requests.models import Response
 from typing import Dict, List
 
@@ -7,5 +8,8 @@ t_Tag = Tag
 
 t_Response = Response
 
+t_DataFrame = DataFrame
+
 t_SummaryDict = Dict[str, Dict[str, Dict[str, int]]]
 t_FullDict = Dict[str, List]
+t_DataFrameDict = Dict[str, DataFrame]
